==> monodevelop_2.0+dfsg.orig.tar.gz: monodevelop-2.0/src/core/MonoDevelop.Projects/MonoDevelop.Projects.Dom/IMethod.cs <==
//
// IMethod.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using MonoDevelop.Projects.Dom.Parser;

namespace MonoDevelop.Projects.Dom
{
	[Flags]
	public enum MethodModifier {	
		None          = 0,
		IsConstructor = 1,
		IsExtension   = 2,
		IsFinalizer   = 4
	}
	
	public interface IMethod : IMember
	{
		MethodModifier MethodModifier {
			get;
		}
		
		bool IsConstructor {
			get;
		}

		bool IsExtension {
			get;
		}
		
		bool IsFinalizer {
			get;
		}
		
		ReadOnlyCollection<IParameter> Parameters {
			get;
		}
		
		ReadOnlyCollection<ITypeParameter> TypeParameters {
			get;
		}
		
		/// <summary>
		/// Returns true, if IsExtension == true and this method extends <param name="type"/>
		/// </summary>
		bool Extends (ProjectDom dom, IType type);
	}
}

==> monodevelop_2.2.1+dfsg.orig.tar.gz: monodevelop-2.2.1/src/core/MonoDevelop.Projects/MonoDevelop.Projects.Dom/IMethod.cs <==
//
// IMethod.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using MonoDevelop.Projects.Dom.Parser;

namespace MonoDevelop.Projects.Dom
{
	[Flags]
	public enum MethodModifier {	
		None          = 0,
		IsConstructor = 1,
		IsExtension   = 2,
		IsFinalizer   = 4,
		WasExtended   = 8
	}
	
	public interface IMethod : IMember
	{
		MethodModifier MethodModifier {
			get;
		}
		
		bool IsConstructor {
			get;
		}

		bool IsExtension {
			get;
		}
		
		bool WasExtended {
			get;
		}
		
		bool IsFinalizer {
			get;
		}
		
		ReadOnlyCollection<ITypeParameter> TypeParameters {
			get;
		}
		
		/// <summary>
		/// Returns true, if IsExtension == true and this method extends <param name="type"/>
		/// </summary>
		IMethod Extends (ProjectDom dom, IType type);
	}
}
